aboutsummaryrefslogtreecommitdiffstats
path: root/radio_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'radio_internal.h')
-rw-r--r--radio_internal.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/radio_internal.h b/radio_internal.h
index ee83eb1..41ca2f2 100644
--- a/radio_internal.h
+++ b/radio_internal.h
@@ -1,20 +1,20 @@
/**
* This file is part of libmsm-h1.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
* libmsm-h1 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* libmsm-h1 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with libmsm-h1. If not, see <http://www.gnu.org/licenses/>.
+ * along with libsamsung-ipc. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -39,22 +39,22 @@
#endif
/* Receive callback */
-void msm_rx_callback(struct msm_request_info *info);
+void ipc_rx_callback(struct ipc_request_info *info);
-void msm_send_get(const int type, int request_id);
-void msm_send_exec(const int type, int request_id);
+void ipc_send_get(const int type, int request_id);
+void ipc_send_exec(const int type, int request_id);
/* Misc */
-void msm_rx_misc_me_sn(struct msm_request_info *info, char *data, int len);
-void msm_rx_misc_time_info(struct msm_request_info *info, char *data, int len);
+void ipc_rx_misc_me_sn(struct ipc_request_info *info, char *data, int len);
+void ipc_rx_misc_time_info(struct ipc_request_info *info, char *data, int len);
/* Net */
-void msm_rx_net_current_plmn(struct msm_request_info *info, char *data, int len);
-void msm_rx_net_plmn_list(struct msm_request_info *info, char *data, int len);
-void msm_rx_net_regist(struct msm_request_info *info, const char *data, int len);
+void ipc_rx_net_current_plmn(struct ipc_request_info *info, char *data, int len);
+void ipc_rx_net_plmn_list(struct ipc_request_info *info, char *data, int len);
+void ipc_rx_net_regist(struct ipc_request_info *info, const char *data, int len);
-struct msm_hdr {
+struct ipc_hdr {
unsigned short frame_len;
unsigned char unk;
unsigned short len;
@@ -1,20 +1,20 @@
/**
- * This file is part of libmsm-h1.
+ * This file is part of libsamsung-ipc.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
@@ -1,20 +1,20 @@
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
- * libmsm-h1 is free software: you can redistribute it and/or modify
+ * libsamsung-ipc is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,20 +1,20 @@
* (at your option) any later version.
*
- * libmsm-h1 is distributed in the hope that it will be useful,
+ * libsamsung-ipc is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the